@@ -25,7 +25,8 @@ count_clades_over_time = function(	tree,
 													min_time		= (if(is.null(min_time)) 0 else min_time),
 													max_time		= (if(is.null(max_time)) Inf else max_time),
 													include_slopes 	= include_slopes);
-		return(list(times			= results$time_points, 
+		return(list(Ntimes			= length(results$time_points),
+					times			= results$time_points, 
 					diversities		= results$diversities, 
 					slopes			= (if(include_slopes) results$slopes else NULL),
 					relative_slopes	= (if(include_slopes) results$relative_slopes else NULL)));
